"""
Main langroid package
"""

from . import mytypes
from . import utils

from . import parsing
from . import prompts
from . import cachedb

from . import language_models
from . import embedding_models

from . import vector_store
from . import agent

from .agent.base import (
    Agent,
    AgentConfig,
)

from .agent.chat_agent import (
    ChatAgent,
    ChatAgentConfig,
)

from .agent.task import Task

from .mytypes import (
    DocMetaData,
    Document,
    Entity,
)

__all__ = [
    "mytypes",
    "utils",
    "parsing",
    "prompts",
    "cachedb",
    "language_models",
    "embedding_models",
    "vector_store",
    "agent",
    "Agent",
    "AgentConfig",
    "ChatAgent",
    "ChatAgentConfig",
    "Task",
    "DocMetaData",
    "Document",
    "Entity",
]



from . import base
from . import chromadb
from . import qdrantdb
from . import meilisearch
from . import lancedb

from .chromadb import ChromaDBConfig, ChromaDB
from .qdrantdb import QdrantDBConfig, QdrantDB
from .meilisearch import MeiliSearch, MeiliSearchConfig
from .lancedb import LanceDB, LanceDBConfig

__all__ = [
    "base",
    "chromadb",
    "qdrantdb",
    "meilisearch",
    "lancedb",
    "ChromaDBConfig",
    "ChromaDB",
    "QdrantDBConfig",
    "QdrantDB",
    "MeiliSearch",
    "MeiliSearchConfig",
    "LanceDB",
    "LanceDBConfig",
]



from langroid.agent.tool_message import ToolMessage


class CypherQueryTool(ToolMessage):
    request: str = "make_query"
    purpose: str = """Use this tool to send me the Generated Cypher query based on 
    text description and schema that I will provide you."""
    cypherQuery: str


class GraphSchemaTool(ToolMessage):
    request: str = "get_schema"
    purpose: str = """Use this tool to get me the schema of the graph database."""
